@@ -13,18 +13,12 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with ingranalyze.  If not, see <http://www.gnu.org/licenses/>.import random
+# along with ingranalyze.  If not, see <http://www.gnu.org/licenses/>.
 
 # -*- coding: utf-8 -*-
 import os
 import tempfile
-from bioasp import asp
-
-#import string
-#from bioasp.misc import *
-#from bioasp.data import op
-#from bioasp.asp import *
-#import sys
+from pyasp.asp import *
 
 root = __file__.rsplit('/', 1)[0]
 
@@ -60,8 +54,8 @@ def get_consistent_labelings(instance,nmodels=0,exclude=[]):
     then the list contain all feasible models.
     '''
     inputs = get_reductions(instance)
-    prg = [ consistency_prg, inputs.to_file(), instance.to_file(), asp.exclude_sol(exclude) ]
-    solver = asp.GringoClasp()
+    prg = [ consistency_prg, inputs.to_file(), instance.to_file(), exclude_sol(exclude) ]
+    solver = GringoClasp()
     models = solver.run(prg,nmodels)
     os.unlink(prg[1])
     os.unlink(prg[2])
@@ -78,9 +72,9 @@ def get_consistent_labelings(instance,nmodels=0,exclude=[]):
     #then the list contain all feasible models.
     #'''
     #inputs = get_reductions(instance)
-    #prg = [ mic_prg, inputs.to_file(), instance.to_file(), asp.exclude_sol(exclude) ] 
+    #prg = [ mic_prg, inputs.to_file(), instance.to_file(), exclude_sol(exclude) ] 
     #options=' --heuristic=Vmtf'
-    #solver = asp.GringoClaspD(options)
+    #solver = GringoClaspD(options)
     #models = solver.run(prg,nmodels)
     #os.unlink(prg[1])
     #os.unlink(prg[2])
@@ -96,9 +90,9 @@ def get_minimal_inconsistent_cores(instance,nmodels=0,exclude=[]):
     then the list contain all feasible models.
     '''
     inputs = get_reductions(instance)
-    prg = [ dyn_mic_prg, inputs.to_file(), instance.to_file(), asp.exclude_sol(exclude) ] 
+    prg = [ dyn_mic_prg, inputs.to_file(), instance.to_file(), exclude_sol(exclude) ] 
     options=' --heuristic=Vmtf'
-    solver = asp.GringoClaspD(options)
+    solver = GringoClaspD(options)
     models = solver.run(prg,nmodels=0,collapseTerms=True, collapseAtoms=False)
     os.unlink(prg[1])
     os.unlink(prg[2])
@@ -107,7 +101,7 @@ def get_minimal_inconsistent_cores(instance,nmodels=0,exclude=[]):
 
 def guess_inputs(instance):
     prg = [ guess_inputs_prg, instance.to_file() ]
-    solver = asp.GringoClasp()
+    solver = GringoClasp()
     models = solver.run(prg,0, collapseTerms=True, collapseAtoms=False)
     os.unlink(prg[1])
     assert(len(models) == 1)
@@ -115,7 +109,7 @@ def guess_inputs(instance):
 
 def get_reductions(instance):
     prg = [ reduction_prg, instance.to_file() ]
-    solver = asp.GringoClasp()
+    solver = GringoClasp()
     models = solver.run(prg,0)
     os.unlink(prg[1])
     assert(len(models) == 1)
@@ -123,48 +117,48 @@ def get_reductions(instance):
 
 
 def get_repair_options_flip_obs(instance):
-    repair_mode = asp.String2TermSet('repair_v')
+    repair_mode = String2TermSet('repair_v')
     instance2 = instance.union(repair_mode)
     prg = [ instance2.to_file(), repair_options_prg ]
-    solver = asp.GringoClasp()
+    solver = GringoClasp()
     models = solver.run(prg)
     os.unlink(prg[0])    
     return models[0]
     
 
 def get_repair_options_flip_edge(instance):
-    repair_mode = asp.String2TermSet('repair_e')
+    repair_mode = String2TermSet('repair_e')
     instance2 = instance.union(repair_mode)
     prg = [ instance2.to_file(), repair_options_prg ]
-    solver = asp.GringoClasp()
+    solver = GringoClasp()
     models = solver.run(prg)
     os.unlink(prg[0])    
     return models[0]
 
 def get_repair_options_make_node_input(instance):
-    repair_mode = asp.String2TermSet('repair_g')
+    repair_mode = String2TermSet('repair_g')
     instance2 = instance.union(repair_mode)
     prg = [ instance2.to_file(), repair_options_prg ]
-    solver = asp.GringoClasp()
+    solver = GringoClasp()
     models = solver.run(prg)
     os.unlink(prg[0])    
     return models[0]
     
       
 def get_repair_options_make_obs_input(instance):
-    repair_mode = asp.String2TermSet('repair_i')
+    repair_mode = String2TermSet('repair_i')
     instance2 = instance.union(repair_mode)
     prg = [ instance2.to_file(), repair_options_prg ]
-    solver = asp.GringoClasp()
+    solver = GringoClasp()
     models = solver.run(prg,1)
     os.unlink(prg[0])    
     return models[0]
     
 def get_repair_options_add_edges(instance):
-    repair_mode = asp.String2TermSet('repair_a')
+    repair_mode = String2TermSet('repair_a')
     instance2 = instance.union(repair_mode)
     prg = [ instance2.to_file(), repair_options_prg ]
-    solver = asp.GringoClasp()
+    solver = GringoClasp()
     models = solver.run(prg)
     os.unlink(prg[0])    
     return models[0]
@@ -173,9 +167,9 @@ def get_repair_options_add_edges(instance):
 def get_minimum_of_repairs(instance,repair_options,exclude=[]):
     inputs = get_reductions(instance)
     instance2 = instance.union(inputs)
-    prg = [ instance2.to_file(),repair_options.to_file(), asp.exclude_sol(exclude), repair_core_prg, repair_cardinality_prg ]
+    prg = [ instance2.to_file(),repair_options.to_file(), exclude_sol(exclude), repair_core_prg, repair_cardinality_prg ]
 
-    solver = asp.GringoClaspOpt()
+    solver = GringoClaspOpt()
     optimum = solver.run(prg)
     os.unlink(prg[0])
     os.unlink(prg[1])
@@ -186,10 +180,10 @@ def get_minimum_of_repairs(instance,repair_options,exclude=[]):
 def get_minimal_repair_sets(instance, repair_options ,optimum,nmodels=0,exclude=[]):
     inputs = get_reductions(instance)
     instance2 = instance.union(inputs)
-    prg = [ instance2.to_file(), repair_options.to_file(), asp.exclude_sol(exclude), repair_core_prg, repair_cardinality_prg ]
+    prg = [ instance2.to_file(), repair_options.to_file(), exclude_sol(exclude), repair_core_prg, repair_cardinality_prg ]
 
     options='--project --opt-all='+str(optimum)
-    solver = asp.GringoClasp(clasp_options=options)
+    solver = GringoClasp(clasp_options=options)
     models = solver.run(prg,nmodels=0, collapseTerms=True, collapseAtoms=False)
     os.unlink(prg[0])
     os.unlink(prg[1])
@@ -209,7 +203,7 @@ def get_predictions_under_minimal_repair(instance, repair_options, optimum):
     prg = [ instance2.to_file(), repair_options.to_file(), prediction_core_prg, repair_cardinality_prg ]
 
     options='--project --enum-mode cautious --opt-all='+str(optimum)
-    solver = asp.GringoClasp(clasp_options=options)
+    solver = GringoClasp(clasp_options=options)
     models = solver.run(prg,nmodels=0,collapseTerms=True, collapseAtoms=False)
     os.unlink(prg[0])
     os.unlink(prg[1])
@@ -226,15 +220,15 @@ def whatsnew(instance,pred):
     [instance] have been deleted. This function is meant to see which of the invariants
     are not a direct consequence of the observations.
     '''
-    accu = asp.TermSet(pred)
+    accu = TermSet(pred)
     for t in instance:
 
         if t.pred() == 'obs_vlabel':
             [_,e,v,s] = t.explode()
-            accu.discard(asp.Term('vlabel',[e,v,s]))
+            accu.discard(Term('vlabel',[e,v,s]))
         elif t.p('obs_elabel'):
             [_,j,i,s] = t.explode()
-            accu.discard(asp.Term('elabel',[j,i,s]))
+            accu.discard(Term('elabel',[j,i,s]))
     return accu
 
 
@@ -246,8 +240,8 @@ def get_predictions_under_consistency(instance):
     '''
     inputs = get_reductions(instance)
 
-    prg = [ prediction_prg, inputs.to_file(), instance.to_file(), asp.exclude_sol([]) ]
-    solver = asp.GringoClasp(clasp_options='--project --enum-mode cautious')
+    prg = [ prediction_prg, inputs.to_file(), instance.to_file(), exclude_sol([]) ]
+    solver = GringoClasp(clasp_options='--project --enum-mode cautious')
     models = solver.run(prg,0,collapseTerms=True, collapseAtoms=False)
     os.unlink(prg[1])
     os.unlink(prg[2])
